==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorppur/acceptance/bean/PurchaseAcceptanceSubEntity.java <==
package com.ejianc.business.proequipmentcorppur.acceptance.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 设备采购-设备验收-设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_acceptance_sub")
public class PurchaseAcceptanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类别id
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 计量单位
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 含税单价
    @TableField(value="contract_num")
    private BigDecimal contractNum; // 合同数量
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 所属合同Id
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率


    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20221027.025620-67-sources.jar: com/ejianc/business/proequipmentcorppur/acceptance/bean/PurchaseAcceptanceSubEntity.java <==
package com.ejianc.business.proequipmentcorppur.acceptance.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 设备采购-设备验收-设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_acceptance_sub")
public class PurchaseAcceptanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类别id
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 计量单位
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 含税单价
    @TableField(value="contract_num")
    private BigDecimal contractNum; // 合同数量
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 所属合同Id
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率

    @TableField(value = "equipment_factory_code")
    private String equipmentFactoryCode; //设备出厂编码
    @TableField(value = "curAccept_standard_section_num")
    private Integer curAcceptStandardSectionNum; //本次验收标准节
    @TableField(value = "accepted_standard_section_num")
    private Integer acceptedStandardSectionNum; //已验收标准节


    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getEquipmentFactoryCode() {
        return equipmentFactoryCode;
    }

    public void setEquipmentFactoryCode(String equipmentFactoryCode) {
        this.equipmentFactoryCode = equipmentFactoryCode;
    }

    public Integer getCurAcceptStandardSectionNum() {
        return curAcceptStandardSectionNum;
    }

    public void setCurAcceptStandardSectionNum(Integer curAcceptStandardSectionNum) {
        this.curAcceptStandardSectionNum = curAcceptStandardSectionNum;
    }

    public Integer getAcceptedStandardSectionNum() {
        return acceptedStandardSectionNum;
    }

    public void setAcceptedStandardSectionNum(Integer acceptedStandardSectionNum) {
        this.acceptedStandardSectionNum = acceptedStandardSectionNum;
    }
}
